==> proshade-0.7.5.1.tar.gz: proshade-0.7.5.1/proshade/documentation/html/_pro_s_h_a_d_e__maths_8hpp.js <==
var _pro_s_h_a_d_e__maths_8hpp =
[
    [ "ProSHADE_rotFun_sphere", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere.html", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere" ],
    [ "BicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator.html", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator" ],
    [ "advanceGLPolyValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4f2619c7f3b8d628af9cb356778e9807", null ],
    [ "arrayMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#aa5a356017340781739a3bd66c716cfa5", null ],
    [ "completeLegendreSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad", null ],
    [ "complexMatrixSVDSigmasOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993", null ],
    [ "complexMatrixSVDUandVOnly", "_pro_s_h_a_d_e__maths_8hpp.html#acdc79bf2506934c9ebbda9c13a2722ad", null ],
    [ "complexMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a254fece06e1cfce122a11ddea4f71970", null ],
    [ "complexMultiplicationConjug", "_pro_s_h_a_d_e__maths_8hpp.html#a2ca5a3aedba75f52aaf707edc4e790f7", null ],
    [ "complexMultiplicationConjugRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#abc59a55f5ed21de90e351005c58a871e", null ],
    [ "complexMultiplicationRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ac9b05344ffead449c29a333a57b404f6", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601", null ],
    [ "evaluateGLSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675", null ],
    [ "findAllPrimes", "_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495", null ],
    [ "findVectorFromThreeVAndThreeD", "_pro_s_h_a_d_e__maths_8hpp.html#ae9f376bb341b192fff008b9b4ef5c603", null ],
    [ "findVectorFromTwoVAndTwoD", "_pro_s_h_a_d_e__maths_8hpp.html#a45fbcfaeaabf9bae2fbd7d46a5fb4bc7", null ],
    [ "gaussLegendreIntegration", "_pro_s_h_a_d_e__maths_8hpp.html#a3d4604176a61820f5fcb95e372861c1d", null ],
    [ "gaussLegendreIntegrationReal", "_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aafc6f1626c7463de53c9f4f6fa11db22", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#a4a379ad8635541b0c7f7f6349822b2a4", null ],
    [ "getEulerZXZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a5750d6f0bf8e4a4b1d26552e8719dfd4", null ],
    [ "getEulerZXZFromAngleAxisFullSearch", "_pro_s_h_a_d_e__maths_8hpp.html#a0ade24485a9272a2d08dd6efb7a54d83", null ],
    [ "getEulerZXZFromRotMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28", null ],
    [ "getEulerZXZFromSOFTPosition", "_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706", null ],
    [ "getGLFirstEvenRoot", "_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2", null ],
    [ "getGLPolyAtZero", "_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432", null ],
    [ "getLegendreAbscAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065", null ],
    [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49", null ],
    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1", null ],
    [ "getSOFTPositionFromEulerZXZ", "_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91", null ],
    [ "multiplyGroupElementMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a18222a942e5fff8eecd15f1235c609e1", null ],
    [ "multiplyTwoSquareMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#ac211e762a46e4c7e25235a651acfdc77", null ],
    [ "normalDistributionValue", "_pro_s_h_a_d_e__maths_8hpp.html#a01087ea3e0db56758d1771618e2e4a45", null ],
    [ "optimiseAxisBiCubicInterpolation", "_pro_s_h_a_d_e__maths_8hpp.html#a51486f6276c28c1b503f19c36007b9e2", null ],
    [ "pearsonCorrCoeff", "_pro_s_h_a_d_e__maths_8hpp.html#a894d87e94446db04492b663e54a74bff", null ],
    [ "prepareBiCubicInterpolatorsMinusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#ac027bbd2cde68eb9d677e8b11b90cc2e", null ],
    [ "prepareBiCubicInterpolatorsMinusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#a73c2321ffcef5079634493d9bf65749b", null ],
    [ "prepareBiCubicInterpolatorsPlusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#a3f12eb80331377a36ee6b3a4f8e65147", null ],
    [ "prepareBiCubicInterpolatorsPlusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a", null ],
    [ "primeFactorsDecomp", "_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e", null ],
    [ "rotationMatrixSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e", null ],
    [ "vectorMeanAndSD", "_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8", null ],
    [ "vectorMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a", null ],
    [ "vectorOrientationSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a2b2f67cba1eea57f19fdaf062db74fde", null ],
    [ "vectorOrientationSimilaritySameDirection", "_pro_s_h_a_d_e__maths_8hpp.html#a79e789452e327bb07a53c5358f4d3eb0", null ],
    [ "zgesdd_", "_pro_s_h_a_d_e__maths_8hpp.html#a0cbbac6da7eaf965ee286850344c51e7", null ]
];

==> proshade-0.7.5.2.tar.gz: proshade-0.7.5.2/proshade/documentation/html/_pro_s_h_a_d_e__maths_8hpp.js <==
var _pro_s_h_a_d_e__maths_8hpp =
[
    [ "ProSHADE_rotFun_sphere", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere.html", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere" ],
    [ "BicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator.html", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator" ],
    [ "advanceGLPolyValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4f2619c7f3b8d628af9cb356778e9807", null ],
    [ "arrayMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#aa5a356017340781739a3bd66c716cfa5", null ],
    [ "completeLegendreSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad", null ],
    [ "complexMatrixSVDSigmasOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993", null ],
    [ "complexMatrixSVDUandVOnly", "_pro_s_h_a_d_e__maths_8hpp.html#acdc79bf2506934c9ebbda9c13a2722ad", null ],
    [ "complexMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a254fece06e1cfce122a11ddea4f71970", null ],
    [ "complexMultiplicationConjug", "_pro_s_h_a_d_e__maths_8hpp.html#a2ca5a3aedba75f52aaf707edc4e790f7", null ],
    [ "complexMultiplicationConjugRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#abc59a55f5ed21de90e351005c58a871e", null ],
    [ "complexMultiplicationRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ac9b05344ffead449c29a333a57b404f6", null ],
    [ "compute3x3MatrixInverse", "_pro_s_h_a_d_e__maths_8hpp.html#a83ac617b105e1ca1729800c5f290b567", null ],
    [ "compute3x3MatrixMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a5f2b9b9da97b52b7e5cccc08493d0e0d", null ],
    [ "compute3x3MatrixVectorMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a2f9c7716f6ab682e8548ab77efcdc444", null ],
    [ "computeCrossProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a61807efeb86ea021f3d17ac531911c3c", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601", null ],
    [ "evaluateGLSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675", null ],
    [ "findAllPrimes", "_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495", null ],
    [ "findRotMatMatchingVectors", "_pro_s_h_a_d_e__maths_8hpp.html#a2b17617f8b3c42c5199948828cd1a57b", null ],
    [ "findVectorFromThreeVAndThreeD", "_pro_s_h_a_d_e__maths_8hpp.html#ae9f376bb341b192fff008b9b4ef5c603", null ],
    [ "findVectorFromTwoVAndTwoD", "_pro_s_h_a_d_e__maths_8hpp.html#a45fbcfaeaabf9bae2fbd7d46a5fb4bc7", null ],
    [ "gaussLegendreIntegration", "_pro_s_h_a_d_e__maths_8hpp.html#a3d4604176a61820f5fcb95e372861c1d", null ],
    [ "gaussLegendreIntegrationReal", "_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aafc6f1626c7463de53c9f4f6fa11db22", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#a4a379ad8635541b0c7f7f6349822b2a4", null ],
    [ "getEulerZXZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a5750d6f0bf8e4a4b1d26552e8719dfd4", null ],
    [ "getEulerZXZFromAngleAxisFullSearch", "_pro_s_h_a_d_e__maths_8hpp.html#a0ade24485a9272a2d08dd6efb7a54d83", null ],
    [ "getEulerZXZFromRotMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28", null ],
    [ "getEulerZXZFromSOFTPosition", "_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706", null ],
    [ "getGLFirstEvenRoot", "_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2", null ],
    [ "getGLPolyAtZero", "_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432", null ],
    [ "getLegendreAbscAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065", null ],
    [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49", null ],
    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1", null ],
    [ "getSOFTPositionFromEulerZXZ", "_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91", null ],
    [ "multiplyGroupElementMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a18222a942e5fff8eecd15f1235c609e1", null ],
    [ "multiplyTwoSquareMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a10bbc3e6e75c26cfbe90664dd2a7d151", null ],
    [ "normalDistributionValue", "_pro_s_h_a_d_e__maths_8hpp.html#a01087ea3e0db56758d1771618e2e4a45", null ],
    [ "optimiseAxisBiCubicInterpolation", "_pro_s_h_a_d_e__maths_8hpp.html#a51486f6276c28c1b503f19c36007b9e2", null ],
    [ "pearsonCorrCoeff", "_pro_s_h_a_d_e__maths_8hpp.html#a894d87e94446db04492b663e54a74bff", null ],
    [ "prepareBiCubicInterpolatorsMinusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#ac027bbd2cde68eb9d677e8b11b90cc2e", null ],
    [ "prepareBiCubicInterpolatorsMinusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#a73c2321ffcef5079634493d9bf65749b", null ],
    [ "prepareBiCubicInterpolatorsPlusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#a3f12eb80331377a36ee6b3a4f8e65147", null ],
    [ "prepareBiCubicInterpolatorsPlusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a", null ],
    [ "primeFactorsDecomp", "_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e", null ],
    [ "rotationMatrixSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e", null ],
    [ "transpose3x3MatrixInPlace", "_pro_s_h_a_d_e__maths_8hpp.html#ac6c48ee69a642f279354789f09b02296", null ],
    [ "vectorMeanAndSD", "_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8", null ],
    [ "vectorMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a", null ],
    [ "vectorOrientationSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a2b2f67cba1eea57f19fdaf062db74fde", null ],
    [ "vectorOrientationSimilaritySameDirection", "_pro_s_h_a_d_e__maths_8hpp.html#a79e789452e327bb07a53c5358f4d3eb0", null ],
    [ "zgesdd_", "_pro_s_h_a_d_e__maths_8hpp.html#a0cbbac6da7eaf965ee286850344c51e7", null ]
];
